@@ -156,7 +156,7 @@ sub _prepare_multicheck_message {
     my $summary;
     my $nr_checks = scalar(@{$self->{checks}});
     if ($code eq OK) {
-        $summary = "All " . $nr_checks . " checks OK";            
+        $summary = "All " . $nr_checks . " checks OK";
     } else {
         my $nr_warnings = scalar(@{$np->messages->{warning} || []});
         my $nr_errors = scalar(@{$np->messages->{critical} || []});
@@ -175,7 +175,7 @@ sub _prepare_multicheck_message {
         }
         $summary = $nr . " of " . $nr_checks . " failed: " . $extra;
     }
-    return ($code,$summary . "\n" . $message);    
+    return ($code,$summary . "\n" . $message);
 }
 
 # Create a formatted prefix for multicheck output
@@ -305,7 +305,6 @@ sub _verify_and_initialize {
 
     # Fetch configuration
     my $config = $self->_get_config($o->config);
-    
     # Now, if a specific check is given, extract it, too.
     my $check_configs;
     $check_configs = $self->_extract_checks($config,$o->check);
@@ -339,8 +338,6 @@ sub verify_check {
     my $check = shift;
     my $name = shift;
     my $np = $self->{np};
-    $self->nagios_die("At least a critical or warning threshold must be given " . $name) 
-      if ((!defined($check->critical) && !defined($check->warning)));        
 }
 
 # Extract one or more check configurations which can be 
@@ -354,7 +351,7 @@ sub _extract_checks {
     if ($check) {
         $self->nagios_die("No configuration given") unless $config;
         $self->nagios_die("No checks defined in configuration") unless $config->{check};
-        
+
         my $check_configs;
         unless ($config->{check}->{$check}) {
             $check_configs = $self->_resolve_multicheck($config,$check,$self->{cmd_args});
@@ -365,17 +362,19 @@ sub _extract_checks {
         }
         $self->nagios_die("No check configuration with name " . $check . " found") unless (@{$check_configs});
 
+        #print Dumper($check_configs);
+
         # Resolve parent values
         for my $c (@{$check_configs}) {
-            # print "[A] ",Dumper($c);
+            #print "[A] ",Dumper($c);
             $self->_resolve_check_config($c,$config,$self->{cmd_args});
             
-            # print "[B] ",Dumper($c);
+            #print "[B] ",Dumper($c);
             # Finally, resolve any left over place holders
             for my $k (keys(%$c)) {
                 $c->{$k} = $self->_replace_placeholder($c->{$k},undef) unless ref($c->{$k});
             }
-            # print "[C] ",Dumper($c);
+            #print "[C] ",Dumper($c);
         }
         return $check_configs;
     } else {
@@ -395,30 +394,28 @@ sub _resolve_multicheck {
     if ($multi_checks)  {
         my $m_check = $multi_checks->{$check};
         if ($m_check) {
-            if ($m_check->{check}) {
-                # Resolve all checks
-                my $c_names = ref($m_check->{check}) eq "ARRAY" ? $m_check->{check} : [ $m_check->{check} ];
-                for my $name (@$c_names) {
-                    my ($c_name,$c_args) = $self->_parse_check_ref($name);
-                    my $args_merged = $self->_merge_multicheck_args($c_args,$args);
+            # Resolve all checks
+            my $c_names = [];
+            for my $type( qw(check multicheck)) {
+                if ($m_check->{$type}) {
+                    push @$c_names, ref($m_check->{$type}) eq "ARRAY" ? @{$m_check->{$type}} : $m_check->{$type};
+                }
+            }
+            for my $name (@$c_names) {
+                my ($c_name,$c_args) = $self->_parse_check_ref($name);
+                my $args_merged = $self->_merge_multicheck_args($c_args,$args);
+                $self->nagios_die("Unknown check '" . $c_name . "' for multi check " . $check) 
+                  unless defined($config->{check}->{$c_name}) or defined($multi_checks->{$c_name});
+                if ($config->{check}->{$c_name}) {
                     # We need a copy of the check hash to avoid mangling it up
                     # if it is referenced multiple times
-                    $self->nagios_die("Unknown check '" . $c_name . "' for multi check " . $check) 
-                      unless defined($config->{check}->{$c_name});
                     my $check = { %{$config->{check}->{$c_name}} };
                     $check->{key} = $c_name;
                     $check->{args} = $args_merged;
                     push @{$check_config},$check;
-                }
-            }
-            if ($m_check->{multicheck}) {
-                my $mc_names = ref($m_check->{multicheck}) eq "ARRAY" ? $m_check->{multicheck} : [ $m_check->{multicheck} ];
-                for my $name (@$mc_names) {                    
-                    my ($mc_name,$mc_args) = $self->_parse_check_ref($name);
-                    my $args_merged = $self->_merge_multicheck_args($mc_args,$args);
-                    $self->nagios_die("Unknown multi check '" . $mc_name . "'")
-                      unless $multi_checks->{$mc_name};
-                    push @{$check_config},@{$self->_resolve_multicheck($config,$mc_name,$args_merged)};
+                } else {
+                    # It's a multi check referenced via <Check> or <MultiCheck> ....
+                    push @{$check_config},@{$self->_resolve_multicheck($config,$c_name,$args_merged)};
                 }
             }
         }
@@ -478,7 +475,7 @@ sub _resolve_check_config {
         }
         # Replace inherited values
         for my $k (keys %$parent_merged) {
-            my $parent_val = $parent_merged->{$k} || "";
+            my $parent_val = defined($parent_merged->{$k}) ?  $parent_merged->{$k} :  "";
             if (defined($check->{$k})) {
                 $check->{$k} =~ s/\$BASE/$parent_val/g;
             } else {
@@ -527,7 +524,13 @@ EOP
     die "Cannot create placeholder regexp" if $@;
     my $rest = $val;
     my $ret = "";
-    while (defined($rest) && length($rest) && $rest =~ $regexp) {        
+    while (defined($rest) && length($rest) && $rest =~ $regexp) {  
+        # $1: start with no placeholder
+        # $2: literal variable as it is defined
+        # $3: variable name (0,1,2,3,...)
+        # $4: same as $3, but either $3 or $4 is defined
+        # $5: default value (if any)
+        # $6: rest which is processed next in the loop
         my $start = defined($1) ? $1 : "";
         my $orig_val = '$' . $2;
         my $i = defined($3) ? $3 : $4;
@@ -563,7 +566,7 @@ EOP
             } else {
                 if (!length($ret)) {
                     # No default value, nothing else for this value. We
-                    # consider at undefined
+                    # consider it undefined
                     return undef;
                 }
             }
@@ -733,8 +736,20 @@ sub add_nagios_np_args {
 
     $np->add_arg(
                  spec => "base|base-alias|b=s",
-                 help => "Base alias name, which when given, interprets critical and warning values as relative in the range 0 .. 100%",
+                 help => "Base name, which when given, interprets critical and warning values as relative in the range 0 .. 100%. Must be given in the form mbean/attribute/path",
                 );
+    $np->add_arg(
+                 spec => "base-mbean=s",
+                 help => "Base MBean name, interprets critical and warning values as relative in the range 0 .. 100%. Requires a base-attribute, too",
+                );
+    $np->add_arg(
+                 spec => "base-attribute=s",
+                 help => "Base attribute for a relative check. Used together with base-mbean",
+                );
+    $np->add_arg(
+                 spec => "base-path=s",
+                 help => "Base path for relatie checks, where this path is used on the base attribute's value",
+                );    
     $np->add_arg(
                  spec => "unit=s",
                  help => "Unit of measurement of the data retreived. Recognized values are [B|KB|MN|GB|TB] for memory values and [us|ms|s|m|h|d] for time values"
@@ -765,6 +780,10 @@ sub add_nagios_np_args {
                  spec => "label|l=s",
                  help => "Label to be used for printing out the result of the check. Placeholders can be used."
                 );
+    $np->add_arg(
+                 spec => "perfdata=s",
+                 help => "Whether performance data should be omitted, which are included by default."
+                );
     $np->add_arg(
                  spec => "unknown-is-critical",
                  help => "Map UNKNOWN errors to errors with a CRITICAL status"
@@ -827,7 +846,7 @@ sub AUTOLOAD {
     my $opts_name = $name;
     $opts_name =~ s/_/-/;
 
-    if ($SERVER_CONFIG_KEYS->{$name}) {        
+    if ($SERVER_CONFIG_KEYS->{$name}) {
         return $np->opts->{$opts_name} if $np->opts->{$opts_name};
         my $c = $SERVER_CONFIG_KEYS->{$name};
         if ($c) {
@@ -851,7 +870,7 @@ sub AUTOLOAD {
 sub nagios_die {
     my $self = shift;
     my @args = @_;
-    
+
     my $np = $self->{np};
     $np->nagios_die(join("",@args),$np->opts->{'unknown-is-critical'} ? CRITICAL : UNKNOWN)
 }
